@@ -91,7 +91,7 @@ function(sgp_object,
 			names(tmp.sim)[(dim(tmp.sim)[2]-1):dim(tmp.sim)[2]] <- c("LOWER_MEDIAN_SGP_95_CONF_BOUND", "UPPER_MEDIAN_SGP_95_CONF_BOUND")
 			tmp <- data.table(merge.data.frame(tmp, tmp.sim, by = unlist(strsplit(as.character(sgp.groups.to.summarize), ", ")),all=TRUE))
 		}
-		print(paste("Finished with", sgp.groups.to.summarize))
+		message(paste("Finished with", sgp.groups.to.summarize))
 		return(tmp)
 	}
 
@@ -116,10 +116,6 @@ function(sgp_object,
 		tmp.simulation.dt <- combineSims(sgp_object); gc()
 	}
 
-	## Set up options for use with doMC
-
-	mc.options <- list(preschedule = FALSE, set.seed = FALSE)
-
 	## Create summary tables
 
 	for (i in summary.groups$institution) {
@@ -130,7 +126,7 @@ function(sgp_object,
 			group.format(summary.groups[["institution_inclusion"]][[i]]),
 			group.format(summary.groups[["demographic"]])), sep=""))
 
-		if (!is.null(confidence.interval.groups)) {
+  	if (!is.null(confidence.interval.groups) & i %in% confidence.interval.groups$institution) {
 			ci.groups <- do.call(paste, c(expand.grid(i,
 				group.format(confidence.interval.groups[["content"]]),
 				group.format(confidence.interval.groups[["time"]]),
@@ -139,15 +135,15 @@ function(sgp_object,
 				group.format(confidence.interval.groups[["demographic"]])), sep=""))
 		}
 
-		if (is.null(confidence.interval.groups)) {
+		if (!is.null(confidence.interval.groups) & i %in% confidence.interval.groups$institution) {
 			j <- k <- NULL ## To prevent R CMD check warnings
-			sgp_object[["Summary"]][[i]] <- foreach(j=iter(sgp.groups), k=iter(rep(FALSE, length(sgp.groups))), 
-				.options.multicore = mc.options, .packages="data.table", .inorder=FALSE) %dopar% {return(sgpSummary(j, k))}
+  		sgp_object[["Summary"]][[i]] <- foreach(j=iter(sgp.groups), k=iter(sgp.groups %in% ci.groups), 
+				.options.multicore=list(preschedule = FALSE, set.seed = FALSE), .packages="data.table", .inorder=FALSE) %dopar% {return(sgpSummary(j, k))}
 			names(sgp_object[["Summary"]][[i]]) <- gsub(", ", "__", sgp.groups)
 		} else {
 			j <- k <- NULL ## To prevent R CMD check warnings
-			sgp_object[["Summary"]][[i]] <- foreach(j=iter(sgp.groups), k=iter(sgp.groups %in% ci.groups), 
-				.options.multicore = mc.options, .packages="data.table", .inorder=FALSE) %dopar% {return(sgpSummary(j, k))}
+    	sgp_object[["Summary"]][[i]] <- foreach(j=iter(sgp.groups), k=iter(rep(FALSE, length(sgp.groups))), 
+				.options.multicore=list(preschedule = FALSE, set.seed = FALSE), .packages="data.table", .inorder=FALSE) %dopar% {return(sgpSummary(j, k))}
 			names(sgp_object[["Summary"]][[i]]) <- gsub(", ", "__", sgp.groups)
 		}
 	} ## END summary.groups$institution summary loop
